##  Scope and Limitations
The Jira integration applies exclusively to initiative fact sheets. Note the following limitations:
  * Only string, number, and date fields are supported for synchronization.
  * The integration does not support real-time synchronization. Data is refreshed every 30 minutes.
